#!/bin/bash
# build code for use at ATNF
set -e
[ $# -eq 0 ] && echo "please specify a version" && exit

Fail () { while [ $# -gt 0 ] ; do echo $1; shift ; done; exit 1; } ;

case `uname` in
    Linux) 
	case `uname -m` in
	    *86)
		PLATFORM=linux 
		;;
	    *86_64)
		PLATFORM=linux64
		;;
	esac
	;;
    SunOS)
	case `uname -r` in
	    4.)
		PLATFORM=sun4
		;;
	    5.*)
		PLATFORM=sun4sol
		;;
	    *)
		case `uname -m` in
		    *86)
			PLATFORM=i86sol 
			;;
		    esac
		esac
	;;
    Darwin)
	case `uname -m` in
	    i*86)
		PLATFORM=darwin_x86
		;;
	    Power*)
		PLATFORM=darwin_ppc
		;;
	esac
	;;
    *)
	Fail "Unsupported on the `uname` platform"
esac

version=$1
InstallDir=/nfs/atapplic/duchamp-${version}
PlatformDir=${InstallDir}/${PLATFORM}
BuildDir=${PlatformDir}/Duchamp-${version}
SymLink=/nfs/atapplic/duchamp

ThisDir=`pwd`
mkdir -p $BuildDir
rm -rf $BuildDir/*
mkdir -p $InstallDir
mkdir -p ${PlatformDir}
rm -f $SymLink
ln -s $InstallDir $SymLink

case `uname` in
  Linux) 
	SVNDir=http://svn.atnf.csiro.au/duchamp/tags/release-${version}
	ConfigOptions="--prefix=${PlatformDir} --with-cfitsio=/usr/local --with-wcslib=/usr/local --with-pgplot=/usr/local --x-libraries=/usr/X11R6/lib"
	MAKE_CMD=make
       	svn checkout $SVNDir $BuildDir
	# The following removes a complier flag that isn't available on draco for gcc 3.3.5
	echo perl -pi -e 's| -ftree-vectorize| |g' ${BuildDir}/Makefile.in
	perl -pi -e 's| -ftree-vectorize| |g' ${BuildDir}/Makefile.in
	;;
  SunOS) 
	DataLocation=/nfs/wwwatdocs/people/Matthew.Whiting/Duchamp/downloads
	ConfigOptions="--prefix=${PlatformDir} --with-cfitsio=/usr/local --with-wcslib=/usr/local --with-pgplot=/usr/local CXX=g++-3.1.1 CC=gcc-3.1.1 F77=g77-3.1.1"
	MAKE_CMD=gmake
	cp ${DataLocation}/Duchamp-${version}.tar.gz ${PlatformDir}; cd ${PlatformDir}; gunzip Duchamp-${version}.tar.gz; tar xvf Duchamp-${version}.tar
	# The following is a patch for a particular issue with the solaris compilers, especially for Duchamp-1.1.8
	perl -pi -e 's|fabsf|fabs|g' Duchamp-${version}/src/PixelMap/Scan.cc
	# The following removes a complier flag that isn't available on cetus for g++-3.1.1
	perl -pi -e 's| -ftree-vectorize| |g' ${BuildDir}/Makefile.in
	;;
  *) Fail "Unsupported on the `uname` platform"
esac

cd $BuildDir

./configure $ConfigOptions

echo "=== Done Configuration. Now to compile the code. ==="

${MAKE_CMD} duchamp

#verification

case `uname` in
    Linux) 
	./VerifyDuchamp.sh
	;;
    SunOS) 
	bash VerifyDuchamp.sh
	;;
    *) Fail "Unsupported on the `uname` platform"
esac

#library, for development purposes only (not necessary to run Duchamp)
${MAKE_CMD} lib

#installation
${MAKE_CMD} install

cp ./README $InstallDir
                    
#Docs
mkdir -p $InstallDir/docs 
cd docs
latex Guide > doc-log
latex Guide >> doc-log
latex Guide >> doc-log
latex Guide >> doc-log
dvips -o Guide.ps Guide.dvi
cp ./Guide.ps  $InstallDir/docs/
export TEXINPUTS=
pdflatex Guide >> doc-log
pdflatex Guide >> doc-log
cp ./Guide.pdf $InstallDir/docs/

#
# Copy the duchamp_wrapper script to /usr/local/bin and make a symlink pointing to it so people can run "Duchamp"
cd $InstallDir
rm -f /usr/local/bin/Duchamp
cp scripts/duchamp-wrapper.sh /usr/local/bin
ln -s /usr/local/bin/duchamp-wrapper.sh /usr/local/bin/Duchamp
# Also copy the library and the include files to /usr/local/lib and /usr/local/include
cp ${PlatformDir}/lib/libduchamp.a /usr/local/lib
cp -r ${PlatformDir}/include/duchamp /usr/local/include

cd $ThisDir
